.. _api_geometry_n_sphere:

.. currentmodule:: microstructpy.geometry.n_sphere

microstructpy.geometry.n_sphere.NSphere
=======================================

.. autoclass:: NSphere
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: